Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(883)

Unified Diff: Source/core/rendering/InlineBox.h

Issue 899163003: Move rendering/RenderObject to layout/LayoutObject. (Closed) Base URL: svn://svn.chromium.org/blink/trunk
Patch Set: Created 5 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: Source/core/rendering/InlineBox.h
diff --git a/Source/core/rendering/InlineBox.h b/Source/core/rendering/InlineBox.h
index bc83cbc5d16a87cbe9e28e08cf24fb57aa91945f..62c34c37ddd4f8603caae9bd84d6eb8a1e19ce6c 100644
--- a/Source/core/rendering/InlineBox.h
+++ b/Source/core/rendering/InlineBox.h
@@ -21,9 +21,9 @@
#ifndef InlineBox_h
#define InlineBox_h
+#include "core/layout/LayoutObject.h"
#include "core/rendering/FloatToLayoutUnit.h"
#include "core/rendering/RenderBoxModelObject.h"
-#include "core/rendering/RenderObjectInlines.h"
#include "platform/graphics/paint/DisplayItemClient.h"
#include "platform/text/TextDirection.h"
@@ -36,11 +36,11 @@ class RootInlineBox;
enum MarkLineBoxes { MarkLineBoxesDirty, DontMarkLineBoxes };
// InlineBox represents a rectangle that occurs on a line. It corresponds to
// some RenderObject (i.e., it represents a portion of that RenderObject).
class InlineBox {
WTF_MAKE_NONCOPYABLE(InlineBox);
public:
- InlineBox(RenderObject& obj)
+ InlineBox(LayoutObject& obj)
: m_next(0)
, m_prev(0)
, m_parent(0)
@@ -52,7 +52,7 @@ public:
{
}
- InlineBox(RenderObject& obj, FloatPointWillBeLayoutPoint topLeft, FloatWillBeLayoutUnit logicalWidth, bool firstLine, bool constructed,
+ InlineBox(LayoutObject& obj, FloatPointWillBeLayoutPoint topLeft, FloatWillBeLayoutUnit logicalWidth, bool firstLine, bool constructed,
bool dirty, bool extracted, bool isHorizontal, InlineBox* next, InlineBox* prev, InlineFlowBox* parent)
: m_next(next)
, m_prev(prev)
@@ -112,7 +112,7 @@ public:
void showLineTreeForThis() const;
virtual void showBox(int = 0) const;
- virtual void showLineTreeAndMark(const InlineBox* = 0, const char* = 0, const InlineBox* = 0, const char* = 0, const RenderObject* = 0, int = 0) const;
+ virtual void showLineTreeAndMark(const InlineBox* = 0, const char* = 0, const InlineBox* = 0, const char* = 0, const LayoutObject* = 0, int = 0) const;
virtual const char* boxName() const;
#endif
@@ -179,7 +179,7 @@ public:
InlineBox* nextLeafChildIgnoringLineBreak() const;
InlineBox* prevLeafChildIgnoringLineBreak() const;
- RenderObject& renderer() const { return m_renderer; }
+ LayoutObject& renderer() const { return m_renderer; }
InlineFlowBox* parent() const
{
@@ -264,7 +264,7 @@ public:
virtual void dirtyLineBoxes();
- virtual RenderObject::SelectionState selectionState() const;
+ virtual LayoutObject::SelectionState selectionState() const;
virtual bool canAccommodateEllipsis(bool ltr, int blockEdge, int ellipsisWidth) const;
// visibleLeftEdge, visibleRightEdge are in the parent's coordinate system.
@@ -385,7 +385,7 @@ private:
InlineBox* m_prev; // The previous element on the same line as us.
InlineFlowBox* m_parent; // The box that contains us.
- RenderObject& m_renderer;
+ LayoutObject& m_renderer;
protected:
// For RootInlineBox
@@ -36,11 +36,11 @@ class RootInlineBox;
enum MarkLineBoxes { MarkLineBoxesDirty, DontMarkLineBoxes };
// InlineBox represents a rectangle that occurs on a line. It corresponds to
-// some RenderObject (i.e., it represents a portion of that RenderObject).
+// some LayoutObject (i.e., it represents a portion of that LayoutObject).
class InlineBox {
WTF_MAKE_NONCOPYABLE(InlineBox);

Powered by Google App Engine
This is Rietveld 408576698